(testing)=

# Testing

The Testing module provides tools for testing the code. This might be part of the integration tests or unit tests.

(assertionsmodule)=

## assertions

```{eval-rst}
.. automodule:: testing.assertions
   :members:

```

(simtelarraymodule)=

## sim_telarray_metadata

```{eval-rst}
.. automodule:: testing.sim_telarray_metadata
   :members:

```

(testconfiguration_module)=

## configuration

```{eval-rst}
.. automodule:: testing.configuration
   :members:

```


(loginspectormodule)=

## log_inspector

```{eval-rst}
.. automodule:: testing.log_inspector
   :members:

```

(validate_outputmodule)=

## validate_output

```{eval-rst}
.. automodule:: testing.validate_output
   :members:
```

(helpersmodule)=

## helpers

```{eval-rst}
.. automodule:: testing.helpers
   :members:
```
